summaryrefslogtreecommitdiff
path: root/actions/register.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-02-12 16:04:43 -0500
committerEvan Prodromou <evan@controlyourself.ca>2009-02-12 16:04:43 -0500
commitb09eb06dae77be27e56d1573de0de7d393950ce5 (patch)
tree5a1a592de20ec840036c9dd71077879090f02ba2 /actions/register.php
parent5c31dcb4304113e40b4a309a18d83dbdb712813e (diff)
Revert "Just discovered the PEAR_Error handling function in index.php. Duh."
This reverts commit 616bdd43a921b2554d21b80af28ddb0fb6cb3c16. Kind of a long hard way to deal with a simple situation, so I'd prefer to just use the global handler.
Diffstat (limited to 'actions/register.php')
-rw-r--r--actions/register.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/actions/register.php b/actions/register.php
index aafb54ebb..853bd0cf6 100644
--- a/actions/register.php
+++ b/actions/register.php
@@ -229,7 +229,7 @@ class RegisterAction extends Action
}
/**
* Handle old fashioned PEAR_Error msgs coming from DB_DataObject
*
* In this case nickname and email don't exist in the DB yet,
* so DB_DataObject throws an error. Overrided from Action.
@@ -239,13 +239,13 @@ class RegisterAction extends Action
* @return nothing
*/
- function handleError($error) {
+ function checkDB_DataObjectError($error) {
if ($error->getCode() == DB_DATAOBJECT_ERROR_NODATA) {
// Do nothing.
} else {
- parent::handleError($error);
+ parent::checkDB_DataObjectError($error);
}
}
@@ -229,7 +229,7 @@ class RegisterAction extends Action
}
/**
- * Handle old fashioned PEAR_Error msgs coming from DB_DataObject
+ * Check old fashioned PEAR_Error msgs coming from DB_DataObject
*
* In this case nickname and email don't exist in the DB yet,